Skip to contents

Two-dimensional micro data masking to handle binary and nominal data

Usage

masking(
  body,
  tb = NULL,
  f1,
  ns,
  Ns,
  cut.off = cut.off,
  glue.mask = glue.mask,
  dec = dec,
  minimal = FALSE
)

Arguments

body

full table body

tb

filtered table body

f1

Subsets indexes of relevant columns

ns

Relevant ns arranged in matrix

Ns

All Ns

cut.off

micro cut point

glue.mask

glue string for masking

dec

decimals

minimal

flag to mask minimally if no overall column is present

Value

tibble